@@ -21,8 +21,7 @@ def replaces_url(meth):
         # If the method is already reflexive, return the result directly.
         if isinstance(url, type(self)):
             return url
-        # _replace() is defined by urecord.
-        return self._replace(url=url)
+        return self._with_url(url)
     return wrapper
 
 
@@ -212,6 +211,13 @@ class API(Record('url', 'http')):
         # Standard case of adding a path component.
         return self.url / item
 
+    def _with_url(self, url):
+        """Replace the URL on this API with another."""
+
+        if not isinstance(url, URLObject):
+            url = URLObject.parse(url)
+        return self._replace(url=url)
+
     @replaces_url
     def _with_file_ext(self, file_ext):
 
